@@ -10,7 +10,7 @@ DEFAULT_DATAFLOW_DOCKERFILE_URL = (
     "https://raw.githubusercontent.com/octue/octue-sdk-python/main/octue/cloud/deployment/google/dataflow/Dockerfile"
 )
 
-OCTUE_SDK_PYTHON_IMAGE_URI = "eu.gcr.io/octue-amy/octue-sdk-python:0.9.3-slim"
+OCTUE_SDK_PYTHON_IMAGE_URI = "octue/octue-sdk-python:0.9.4-slim"
 
 
 class DataflowDeployer(BaseDeployer):
@@ -34,10 +34,10 @@ class DataflowDeployer(BaseDeployer):
     :return None:
     """
 
-    TOTAL_NUMBER_OF_STAGES = 4
+    TOTAL_NUMBER_OF_STAGES = 3
 
-    def __init__(self, octue_configuration_path, service_id=None):
-        super().__init__(octue_configuration_path, service_id)
+    def __init__(self, octue_configuration_path, service_id=None, image_uri_template=None):
+        super().__init__(octue_configuration_path, service_id, image_uri_template)
         self.build_trigger_description = f"Build the {self.name!r} service and deploy it to Dataflow."
         self.success_message = f"[SUCCESS] Service deployed - it can be questioned via Pub/Sub at {self.service_id!r}."
 
@@ -47,25 +47,55 @@ class DataflowDeployer(BaseDeployer):
         )
         self.setup_file_path = self._octue_configuration.get("setup_file_path", DEFAULT_SETUP_FILE_PATH)
 
-    def deploy(self, no_cache=False, update=False, dataflow_job_only=False):
+    def deploy(self, no_cache=False, update=False):
         """Create a Google Cloud Build configuration from the `octue.yaml file, create a build trigger, run it, and
         deploy the app as a Google Dataflow streaming job.
 
         :param bool no_cache: if `True`, don't use the Docker cache when building the image
         :param bool update: if `True`, allow the build trigger to already exist and just build and deploy a new image based on an updated `octue.yaml` file
-        :param bool dataflow_job_only: if `True`, skip creating and running the build trigger and just deploy a pre-built image to Dataflow
         :return None:
         """
-        if dataflow_job_only:
-            self._deploy_streaming_dataflow_job(update=update)
-            print(self.success_message)
-            return
-
         self._generate_cloud_build_configuration(no_cache=no_cache)
         self._create_build_trigger(update=update)
         self._run_build_trigger()
         print(self.success_message)
 
+    def create_streaming_dataflow_job(self, image_uri, update=False):
+        """Deploy the newly-built service as a streaming Dataflow job.
+
+        :param str image_uri: the URI of the image to use in the Dataflow job
+        :param bool update: if `True`, update the identically-named existing job
+        :return None:
+        """
+        with ProgressMessage("Deploying streaming Dataflow job", 1, 1) as progress_message:
+            if update:
+                progress_message.finish_message = "update triggered."
+
+            kwargs = {
+                "service_name": self.name,
+                "project_name": self.project_name,
+                "service_id": self.service_id,
+                "region": self.region,
+                "setup_file_path": self.setup_file_path,
+                "image_uri": image_uri,
+                "temporary_files_location": self.temporary_files_location,
+                "update": update,
+            }
+
+            try:
+                create_streaming_job(**kwargs)
+
+            except ValueError as error:
+                if not update:
+                    raise error
+
+                # If attempting to update a job that doesn't yet exist, set `update` to `False`.
+                kwargs["update"] = False
+                progress_message.finish_message = "triggered."
+                create_streaming_job(**kwargs)
+
+        print(self.success_message)
+
     def _generate_cloud_build_configuration(self, no_cache=False):
         """Generate a Google Cloud Build configuration equivalent to a `cloudbuild.yaml` file in memory and assign it
         to the `generated_cloud_build_configuration` attribute. The configuration steps are:
@@ -81,8 +111,11 @@ class DataflowDeployer(BaseDeployer):
             1,
             self.TOTAL_NUMBER_OF_STAGES,
         ) as progress_message:
+
             if self.provided_cloud_build_configuration_path:
-                progress_message.finish_message = "skipped - using cloudbuild.yaml file from repository."
+                progress_message.finish_message = (
+                    f"skipped - using {self._octue_configuration['cloud_build_configuration_path']!r} from repository."
+                )
                 return
 
             get_dockerfile_step, dockerfile_path = self._create_get_dockerfile_step(DEFAULT_DATAFLOW_DOCKERFILE_URL)
@@ -101,9 +134,12 @@ class DataflowDeployer(BaseDeployer):
                         "args": [
                             "build",
                             *cache_option,
-                            *[f"--build-arg={variable}" for variable in self.required_environment_variables],
+                            *[
+                                f"--build-arg={name}={value}"
+                                for name, value in self.required_environment_variables.items()
+                            ],
                             "-t",
-                            self.image_uri,
+                            self.image_uri_template,
                             ".",
                             "-f",
                             dockerfile_path,
@@ -112,7 +148,7 @@ class DataflowDeployer(BaseDeployer):
                     {
                         "id": "Push image",
                         "name": "gcr.io/cloud-builders/docker",
-                        "args": ["push", self.image_uri],
+                        "args": ["push", self.image_uri_template],
                     },
                     {
                         "id": "Deploy Dataflow job",
@@ -124,40 +160,9 @@ class DataflowDeployer(BaseDeployer):
                             f"--service-id={self.service_id}",
                             "--update",
                             "--dataflow-job-only",
+                            f"--image-uri={self.image_uri_template}",
                         ],
                     },
                 ],
-                "images": [self.image_uri],
+                "images": [self.image_uri_template],
             }
-
-    def _deploy_streaming_dataflow_job(self, update=False):
-        """Deploy the newly-built service as a streaming Dataflow job.
-
-        :param bool update: if `True`, update the identically-named existing job
-        :return None:
-        """
-        with ProgressMessage("Deploying streaming Dataflow job", 4, self.TOTAL_NUMBER_OF_STAGES) as progress_message:
-            if update:
-                progress_message.finish_message = "update triggered."
-
-            kwargs = {
-                "service_name": self.name,
-                "project_name": self.project_name,
-                "service_id": self.service_id,
-                "region": self.region,
-                "setup_file_path": self.setup_file_path,
-                "image_uri": self.image_uri,
-                "temporary_files_location": self.temporary_files_location,
-                "update": update,
-            }
-
-            try:
-                create_streaming_job(**kwargs)
-
-            except ValueError as error:
-                if not update:
-                    raise error
-
-                # If attempting to update a job that doesn't yet exist, set `update` to `False`.
-                kwargs["update"] = False
-                create_streaming_job(**kwargs)
